@@ -4,6 +4,7 @@ import logging
 # external imports
 from eth_contract_registry.registry import Registry
 from chainlib.eth.constant import ZERO_ADDRESS
+from chainlib.eth.address import is_same_address
 from hexathon import (
         strip_0x,
         add_0x,
@@ -15,7 +16,7 @@ logg = logging.getLogger(__name__)
 
 
 def is_empty_response(v):
-    return v == None or v == ZERO_ADDRESS or strip_0x(v, allow_empty=True) == ''
+    return v == None or is_same_address(v, ZERO_ADDRESS) or strip_0x(v, allow_empty=True) == ''
 
 
 class CICRegistry:
@@ -60,7 +61,7 @@ class CICRegistry:
         for lookup in self.lookups:
             logg.debug('executing lookup {} for name {}'.format(str(lookup), name))
             address = lookup.by_name(self.rpc, name, sender_address)
-            if not is_empty_response(address) and not add_0x(address) == ZERO_ADDRESS:
+            if not is_empty_response(address) and not is_same_address(address, ZERO_ADDRESS):
                 logg.info('lookup {} found {} for name {}'.format(str(lookup), address, name))
                 return address
 
